@@ -13,11 +13,8 @@
 
 #include "vim.h"
 
-// cproto fails on missing include files
-#ifndef PROTO
-# ifdef FEAT_TOOLBAR
-#  include <photon/PxImage.h>
-# endif
+#ifdef FEAT_TOOLBAR
+# include <photon/PxImage.h>
 #endif
 
 #if !defined(__QNX__)
@@ -348,7 +345,10 @@ gui_ph_handle_timer_cursor(
 }
 
     static int
-gui_ph_handle_timer_timeout(PtWidget_t *widget, void *data, PtCallbackInfo_t *info)
+gui_ph_handle_timer_timeout(
+    PtWidget_t		*widget,
+    void		*data,
+    PtCallbackInfo_t	*info)
 {
     is_timeout = TRUE;
 
@@ -361,7 +361,8 @@ gui_ph_handle_window_cb(PtWidget_t *widget, void *data, PtCallbackInfo_t *info)
     PhWindowEvent_t *we = info->cbdata;
     ushort_t *width, *height;
 
-    switch (we->event_f) {
+    switch (we->event_f)
+    {
 	case Ph_WM_CLOSE:
 	    gui_shell_closed();
 	    break;
@@ -976,7 +977,7 @@ gui_ph_is_buffer_item(vimmenu_T *menu, vimmenu_T *parent)
 	if (mark != NULL)
 	{
 	    mark++;
-	    while (isdigit(*mark))
+	    while (SAFE_isdigit(*mark))
 		mark++;
 
 	    if (*mark == ')')
@@ -992,19 +993,19 @@ gui_ph_pg_add_buffer(char *name)
     char **new_titles = NULL;
 
     new_titles = ALLOC_MULT(char *, (num_panels + 1));
-    if (new_titles != NULL)
-    {
-	if (num_panels > 0)
-	    memcpy(new_titles, panel_titles, num_panels * sizeof(char **));
+    if (new_titles == NULL)
+	return;
 
-	new_titles[ num_panels++ ] = name;
+    if (num_panels > 0)
+	memcpy(new_titles, panel_titles, num_panels * sizeof(char **));
 
-	PtSetResource(gui.vimPanelGroup, Pt_ARG_PG_PANEL_TITLES, new_titles,
-		num_panels);
+    new_titles[ num_panels++ ] = name;
 
-	vim_free(panel_titles);
-	panel_titles = new_titles;
-    }
+    PtSetResource(gui.vimPanelGroup, Pt_ARG_PG_PANEL_TITLES, new_titles,
+	    num_panels);
+
+    vim_free(panel_titles);
+    panel_titles = new_titles;
 }
 
     static void
@@ -1373,7 +1374,7 @@ gui_mch_wait_for_chars(int wtime)
     }
 }
 
-#if defined(FEAT_BROWSE) || defined(PROTO)
+#if defined(FEAT_BROWSE)
 /*
  * Put up a file requester.
  * Returns the selected name in allocated memory, or NULL for Cancel.
@@ -1399,7 +1400,7 @@ gui_mch_browse(
     char_u  *open_text = NULL;
 
     flags = 0;
-    memset(&file, 0, sizeof(file));
+    CLEAR_FIELD(file);
 
     default_path = alloc(MAXPATHL + 1 + NAME_MAX + 1);
     if (default_path != NULL)
@@ -1453,7 +1454,7 @@ gui_mch_browse(
 }
 #endif
 
-#if defined(FEAT_GUI_DIALOG) || defined(PROTO)
+#if defined(FEAT_GUI_DIALOG)
 static PtWidget_t *gui_ph_dialog_text = NULL;
 
     static int
@@ -1475,7 +1476,10 @@ gui_ph_dialog_close(int button, void *data)
 }
 
     static int
-gui_ph_dialog_text_enter(PtWidget_t *widget, void *data, PtCallbackInfo_t *info)
+gui_ph_dialog_text_enter(
+    PtWidget_t		*widget,
+    void		*data,
+    PtCallbackInfo_t	*info)
 {
     if (info->reason_subtype == Pt_EDIT_ACTIVATE)
 	gui_ph_dialog_close(1, data);
@@ -1559,7 +1563,7 @@ gui_mch_dialog(
 		}
 	    }
 	}
-#ifndef FEAT_GUI_TEXTDIALOG
+# ifndef FEAT_GUI_TEXTDIALOG
 	dialog_result = PtAlert(
 		gui.vimWindow, NULL,
 		title,
@@ -1567,7 +1571,7 @@ gui_mch_dialog(
 		message, NULL,
 		button_count, (const char **) button_array, NULL,
 		default_button, 0, Pt_MODAL);
-#else
+# else
 	// Writing the dialog ourselves lets us add extra features, like
 	// trapping the escape key and returning 0 to vim
 	{
@@ -1577,8 +1581,8 @@ gui_mch_dialog(
 	    PtModalCtrl_t modal_ctrl;
 	    PtDialogInfo_t di;
 
-	    memset(&di, 0, sizeof(di));
-	    memset(&modal_ctrl, 0, sizeof(modal_ctrl));
+	    CLEAR_FIELD(di);
+	    CLEAR_FIELD(modal_ctrl);
 
 	    n = 0;
 	    PtSetArg(&args[n++], Pt_ARG_GROUP_ROWS_COLS, 0, 0);
@@ -1632,7 +1636,7 @@ gui_mch_dialog(
 	    PtDestroyWidget(dialog);
 	    gui_ph_dialog_text = NULL;
 	}
-#endif
+# endif
     }
 
     vim_free(button_array);
@@ -1706,14 +1710,14 @@ gui_mch_iconify(void)
 {
     PhWindowEvent_t event;
 
-    memset(&event, 0, sizeof (event));
+    CLEAR_FIELD(event);
     event.event_f = Ph_WM_HIDE;
     event.event_state = Ph_WM_EVSTATE_HIDE;
     event.rid = PtWidgetRid(gui.vimWindow);
     PtForwardWindowEvent(&event);
 }
 
-#if defined(FEAT_EVAL) || defined(PROTO)
+#if defined(FEAT_EVAL)
 /*
  * Bring the Vim window to the foreground.
  */
@@ -1722,7 +1726,7 @@ gui_mch_set_foreground(void)
 {
     PhWindowEvent_t event;
 
-    memset(&event, 0, sizeof (event));
+    CLEAR_FIELD(event);
     event.event_f = Ph_WM_TOFRONT;
     event.event_state = Ph_WM_EVSTATE_FFRONT;
     event.rid = PtWidgetRid(gui.vimWindow);
@@ -1845,7 +1849,7 @@ gui_mch_destroy_scrollbar(scrollbar_T *sb)
 ////////////////////////////////////////////////////////////////////////////
 // Mouse functions
 
-#if defined(FEAT_MOUSESHAPE) || defined(PROTO)
+#if defined(FEAT_MOUSESHAPE)
 // The last set mouse pointer shape is remembered, to be used when it goes
 // from hidden to not hidden.
 static int last_shape = 0;
@@ -1901,21 +1905,21 @@ mch_set_mouse_shape(int shape)
     void
 gui_mch_mousehide(int hide)
 {
-    if (gui.pointer_hidden != hide)
-    {
-	gui.pointer_hidden = hide;
+    if (gui.pointer_hidden == hide)
+	return;
+
+    gui.pointer_hidden = hide;
 #ifdef FEAT_MOUSESHAPE
-	if (hide)
-	    PtSetResource(gui.vimTextArea, Pt_ARG_CURSOR_TYPE,
-		    Ph_CURSOR_NONE, 0);
-	else
-	    mch_set_mouse_shape(last_shape);
-#else
+    if (hide)
 	PtSetResource(gui.vimTextArea, Pt_ARG_CURSOR_TYPE,
-		(hide == MOUSE_SHOW) ? GUI_PH_MOUSE_TYPE : Ph_CURSOR_NONE,
-		0);
+		Ph_CURSOR_NONE, 0);
+    else
+	mch_set_mouse_shape(last_shape);
+#else
+    PtSetResource(gui.vimTextArea, Pt_ARG_CURSOR_TYPE,
+	    (hide == MOUSE_SHOW) ? GUI_PH_MOUSE_TYPE : Ph_CURSOR_NONE,
+	    0);
 #endif
-    }
 }
 
     void
@@ -1977,11 +1981,11 @@ gui_mch_new_colors(void)
 	g = PgGreenValue(gui_ph_mouse_color) ^ 255;
 	b = PgBlueValue(gui_ph_mouse_color) ^ 255;
 
-#ifndef FEAT_MOUSESHAPE
+# ifndef FEAT_MOUSESHAPE
 	gui_ph_mouse_color = PgRGB(r, g, b);
 	PtSetResource(gui.vimTextArea, Pt_ARG_CURSOR_COLOR,
 		gui_ph_mouse_color, 0);
-#endif
+# endif
     }
 #endif
 
@@ -2349,7 +2353,7 @@ gui_mch_haskey(char_u *name)
 // Menu
 
 #ifdef FEAT_TOOLBAR
-#include "toolbar.phi"
+# include "toolbar.phi"
 
 static PhImage_t *gui_ph_toolbar_images[] = {
     &tb_new_phi,
@@ -2442,7 +2446,7 @@ gui_ph_toolbar_find_icon(vimmenu_T *menu)
 }
 #endif
 
-#if defined(FEAT_MENU) || defined(PROTO)
+#if defined(FEAT_MENU)
     void
 gui_mch_enable_menu(int flag)
 {
@@ -2544,7 +2548,7 @@ gui_mch_add_menu(vimmenu_T *menu, int index)
 
 	    if (menu->mnemonic != 0)
 	    {
-		PtAddHotkeyHandler(gui.vimWindow, tolower(menu->mnemonic),
+		PtAddHotkeyHandler(gui.vimWindow, SAFE_tolower(menu->mnemonic),
 			Pk_KM_Alt, 0, menu, gui_ph_handle_pulldown_menu);
 	    }
 	}
@@ -2575,7 +2579,7 @@ gui_mch_add_menu_item(vimmenu_T *menu, int index)
     n = 0;
     PtSetArg(&args[ n++ ], Pt_ARG_POINTER, menu, 0);
 
-#ifdef FEAT_TOOLBAR
+# ifdef FEAT_TOOLBAR
     if (menu_is_toolbar(parent->name))
     {
 	if (menu_is_separator(menu->name))
@@ -2626,7 +2630,7 @@ gui_mch_add_menu_item(vimmenu_T *menu, int index)
 	    PtRealizeWidget(menu->id);
     }
     else
-#endif
+# endif
 	if (menu_is_separator(menu->name))
     {
 	menu->id = PtCreateWidget(PtSeparator, parent->submenu_id, n, args);
@@ -2651,14 +2655,14 @@ gui_mch_add_menu_item(vimmenu_T *menu, int index)
 
 	PtAddCallback(menu->id, Pt_CB_ACTIVATE, gui_ph_handle_menu, menu);
 
-#ifdef USE_PANEL_GROUP
+# ifdef USE_PANEL_GROUP
 	if (gui_ph_is_buffer_item(menu, parent) == TRUE)
 	{
 	    PtAddCallback(menu->id, Pt_CB_DESTROYED,
 		    gui_ph_handle_buffer_remove, menu);
 	    gui_ph_pg_add_buffer(menu->dname);
 	}
-#endif
+# endif
     }
 
     gui_ph_position_menu(menu->id, menu->priority);
@@ -2733,7 +2737,7 @@ gui_mch_toggle_tearoffs(int enable)
 
 #endif
 
-#if defined(FEAT_TOOLBAR) || defined(PROTO)
+#if defined(FEAT_TOOLBAR)
     void
 gui_mch_show_toolbar(int showit)
 {
@@ -2828,7 +2832,7 @@ gui_ph_parse_font_name(
 	{
 	    while (*mark != NUL && *mark++ == ':')
 	    {
-		switch (tolower(*mark++))
+		switch (SAFE_tolower(*mark++))
 		{
 		    case 'a': *font_flags |= PF_STYLE_ANTIALIAS; break;
 		    case 'b': *font_flags |= PF_STYLE_BOLD; break;
@@ -2955,12 +2959,12 @@ gui_mch_get_font(char_u *vim_font_name, int report_error)
     }
 
     if (report_error)
-	semsg(e_unknown_font_str, vim_font_name);
+	semsg(_(e_unknown_font_str), vim_font_name);
 
     return FAIL;
 }
 
-#if defined(FEAT_EVAL) || defined(PROTO)
+#if defined(FEAT_EVAL)
 /*
  * Return the name of font "font" in allocated memory.
  * Don't know how to get the actual name, thus use the provided name.
