@@ -764,6 +764,65 @@ list_insert(list_T *l, listitem_T *ni, listitem_T *item)
     }
 }
 
+/*
+ * Append a new empty item into "l" based on the list item type.  Used when
+ * adding a new element to a List in Vim9script by using the current list
+ * length as the index.
+ */
+    static int
+list_append_new_item(list_T *l)
+{
+    typval_T	tv;
+
+    if (l->lv_type != NULL && l->lv_type->tt_member != NULL)
+	tv.v_type = l->lv_type->tt_member->tt_type;
+    else
+	tv.v_type = VAR_NUMBER;
+    tv.v_lock = 0;
+
+    switch (tv.v_type)
+    {
+	case VAR_BOOL: tv.vval.v_number = VVAL_FALSE; break;
+	case VAR_SPECIAL: tv.vval.v_number = 0; break;
+	case VAR_NUMBER: tv.vval.v_number = 0; break;
+	case VAR_FLOAT: tv.vval.v_float = 0; break;
+	case VAR_STRING: tv.vval.v_string = NULL; break;
+	case VAR_BLOB: tv.vval.v_blob = blob_alloc(); break;
+	case VAR_FUNC: tv.vval.v_string = NULL; break;
+	case VAR_PARTIAL: tv.vval.v_partial = NULL; break;
+	case VAR_LIST: tv.vval.v_list = list_alloc(); break;
+	case VAR_DICT: tv.vval.v_dict = dict_alloc(); break;
+#ifdef FEAT_JOB_CHANNEL
+	case VAR_JOB: tv.vval.v_job = NULL; break;
+	case VAR_CHANNEL: tv.vval.v_channel = NULL; break;
+#endif
+	case VAR_CLASS:
+	    if (l->lv_type != NULL && l->lv_type->tt_member != NULL)
+		tv.vval.v_class = l->lv_type->tt_member->tt_class;
+	    else
+		tv.vval.v_class = NULL;
+	    break;
+	case VAR_OBJECT:
+	    if (l->lv_type != NULL && l->lv_type->tt_member != NULL)
+		tv.vval.v_object =
+		    alloc_object(l->lv_type->tt_member->tt_class);
+	    else
+		tv.vval.v_object = NULL;
+	    break;
+	case VAR_TYPEALIAS: tv.vval.v_typealias = NULL; break;
+	case VAR_TUPLE: tv.vval.v_tuple = tuple_alloc(); break;
+	default:
+	    tv.v_type = VAR_NUMBER;
+	    tv.vval.v_number = 0;
+	    break;
+    }
+
+    if (l->lv_type != NULL && l->lv_type->tt_member != NULL)
+	set_tv_type(&tv, l->lv_type->tt_member);
+
+    return list_append_tv(l, &tv);
+}
+
 /*
  * Get the list item in "l" with index "n1".  "n1" is adjusted if needed.
  * In Vim9, it is at the end of the list, add an item if "can_append" is TRUE.
@@ -782,7 +841,8 @@ check_range_index_one(list_T *l, long *n1, int can_append, int quiet)
     if (can_append && in_vim9script()
 	    && *n1 == l->lv_len && l->lv_lock == 0)
     {
-	list_append_number(l, 0);
+	if (list_append_new_item(l) == FAIL)
+	    return NULL;
 	li = list_find_index(l, n1);
     }
     if (li == NULL)
@@ -1265,7 +1325,21 @@ list_slice_or_index(
     {
 	// copy the item to "var1" to avoid that freeing the list makes it
 	// invalid.
-	copy_tv(&list_find(list, n1)->li_tv, &var1);
+	listitem_T *li = check_range_index_one(list, (long *)&n1, TRUE, TRUE);
+	if (li == NULL)
+	    return FAIL;
+	copy_tv(&li->li_tv, &var1);
+
+	// If "var1" is a List and the List item type is not set, then set it
+	// from the declared list item type.
+	if (in_vim9script() && var1.v_type == VAR_LIST
+					&& var1.vval.v_list != NULL
+					&& var1.vval.v_list->lv_type == NULL)
+	{
+	    if (list->lv_type != NULL && list->lv_type->tt_member != NULL)
+		set_tv_type(&var1, list->lv_type->tt_member);
+	}
+
 	clear_tv(rettv);
 	*rettv = var1;
     }
