@@ -9,20 +9,20 @@
  * See README.txt for an overview of the Vim source code.
  */
 
-#include	"vim.h"
+#include "vim.h"
 
 // define _generic_64 for use in time functions
-#if !defined(VAX) && !defined(PROTO)
-#   include <gen64def.h>
+#if !defined(VAX)
+# include <gen64def.h>
 #else
 // based on Alpha's gen64def.h; the file is absent on VAX
 typedef struct _generic_64 {
-#   pragma __nomember_alignment
-    __union  {				// You can treat me as...
+# pragma __nomember_alignment
+    __union  {				     // You can treat me as...
 	// long long is not available on VAXen
 	// unsigned __int64 gen64$q_quadword; ...a single 64-bit value, or
 
-	unsigned int gen64$l_longword [2]; // ...two 32-bit values, or
+	unsigned int gen64$l_longword [2];   // ...two 32-bit values, or
 	unsigned short int gen64$w_word [4]; // ...four 16-bit values
     } gen64$r_quad_overlay;
 } GENERIC_64;
@@ -118,7 +118,8 @@ mch_settmode(tmode_T tmode)
 
     if ( tmode == TMODE_RAW )
 	set_tty(0, 0);
-    else{
+    else
+    {
 	switch (orgmode.width)
 	{
 	    case 132:	OUT_STR_NF((char_u *)"\033[?3h\033>");	break;
@@ -379,16 +380,19 @@ vms_wproc(char *name, int val)
 	return 1;
 
     // accept all DECC$K_FILE and DECC$K_DIRECTORY
-    if (vms_match_num == 0) {
+    if (vms_match_num == 0)
+    {
 	// first time through, setup some things
-	if (NULL == vms_fmatch) {
+	if (NULL == vms_fmatch)
+	{
 	    vms_fmatch = ALLOC_MULT(char_u *, EXPL_ALLOC_INC);
 	    if (!vms_fmatch)
 		return 0;
 	    vms_match_alloced = EXPL_ALLOC_INC;
 	    vms_match_free = EXPL_ALLOC_INC;
 	}
-	else {
+	else
+	{
 	    // re-use existing space
 	    vms_match_free = vms_match_alloced;
 	}
@@ -399,11 +403,13 @@ vms_wproc(char *name, int val)
     name=vms_tolower(name);
 
     // if name already exists, don't add it
-    for (i = 0; i<vms_match_num; i++) {
+    for (i = 0; i<vms_match_num; i++)
+    {
 	if (0 == STRCMP((char_u *)name,vms_fmatch[i]))
 	    return 1;
     }
-    if (--vms_match_free == 0) {
+    if (--vms_match_free == 0)
+    {
 	char_u **old_vms_fmatch = vms_fmatch;
 
 	// add more space to store matches
@@ -437,7 +443,12 @@ vms_wproc(char *name, int val)
  *
  */
     int
-mch_expand_wildcards(int num_pat, char_u **pat, int *num_file, char_u ***file, int flags)
+mch_expand_wildcards(
+    int		num_pat,
+    char_u	**pat,
+    int		*num_file,
+    char_u	***file,
+    int		flags)
 {
     int		i, cnt = 0;
     char_u	buf[MAXPATHL];
@@ -464,9 +475,12 @@ mch_expand_wildcards(int num_pat, char_u **pat, int *num_file, char_u ***file, i
 
 	vms_match_num = 0; // reset collection counter
 	result = decc$translate_vms(vms_fixfilename(buf));
-	if ( (int) result == 0 || (int) result == -1  ) {
+	if ( (int) result == 0 || (int) result == -1  )
+	{
 	    cnt = 0;
-	} else {
+	}
+	else
+	{
 	    cnt = decc$to_vms(result, vms_wproc, 1 /*allow wild*/ , (flags & EW_DIR ? 0:1 ) /*allow directory*/) ;
 	}
 	if (cnt > 0)
@@ -524,9 +538,12 @@ mch_expandpath(garray_T *gap, char_u *path, int flags)
     // the result from the decc$translate_vms needs to be handled
     // otherwise it might create ACCVIO error in decc$to_vms
     result = decc$translate_vms(vms_fixfilename(path));
-    if ( (int) result == 0 || (int) result == -1  ) {
+    if ( (int) result == 0 || (int) result == -1  )
+    {
 	cnt = 0;
-    } else {
+    }
+    else
+    {
 	cnt = decc$to_vms(result, vms_wproc, 1 /*allow_wild*/, (flags & EW_DIR ? 0:1 ) /*allow directory*/);
     }
     if (cnt > 0)
@@ -554,7 +571,8 @@ vms_unix_mixed_filespec(char *in, char *out)
     // copy vms filename portion up to last colon
     // (node and/or disk)
     lastcolon = strrchr(in, ':');   // find last colon
-    if (lastcolon != NULL) {
+    if (lastcolon != NULL)
+    {
 	len = lastcolon - in + 1;
 	strncpy(out, in, len);
 	out += len;
@@ -565,26 +583,35 @@ vms_unix_mixed_filespec(char *in, char *out)
 
     // start of directory portion
     ch = *in;
-    if ((ch == '[') || (ch == '/') || (ch == '<')) {	// start of directory(s) ?
+    if ((ch == '[') || (ch == '/') || (ch == '<')) // start of directory(s) ?
+    {
 	ch = '[';
 	SKIP_FOLLOWING_SLASHES(in);
-    } else if (EQN(in, "../", 3)) { // Unix parent directory?
+    }
+    else if (EQN(in, "../", 3))      // Unix parent directory?
+    {
 	*out++ = '[';
 	*out++ = '-';
 	end_of_dir = out;
 	ch = '.';
 	in += 2;
 	SKIP_FOLLOWING_SLASHES(in);
-    } else {		    // not a special character
-	while (EQN(in, "./", 2)) {	// Ignore Unix "current dir"
+    }
+    else
+    {                                // not a special character
+	while (EQN(in, "./", 2))     // Ignore Unix "current dir"
+	{
 	    in += 2;
 	    SKIP_FOLLOWING_SLASHES(in);
     }
-    if (strchr(in, '/') == NULL) {  // any more Unix directories ?
-	strcpy(out, in);	// No - get rest of the spec
+    if (strchr(in, '/') == NULL)     // any more Unix directories ?
+    {
+	strcpy(out, in);             // No - get rest of the spec
 	return;
-    } else {
-	*out++ = '[';	    // Yes, denote a Vms subdirectory
+    }
+    else
+    {
+	*out++ = '[';                // Yes, denote a Vms subdirectory
 	ch = '.';
 	--in;
 	}
@@ -596,26 +623,31 @@ vms_unix_mixed_filespec(char *in, char *out)
     *out++ = ch;
     ++in;
 
-    while (*in != '\0') {
+    while (*in != '\0')
+    {
 	ch = *in;
-	if ((ch == ']') || (ch == '/') || (ch == '>') ) {	// end of (sub)directory ?
+	if ((ch == ']') || (ch == '/') || (ch == '>') )	// end of (sub)directory ?
+	{
 	    end_of_dir = out;
 	    ch = '.';
 	    SKIP_FOLLOWING_SLASHES(in);
 	    }
-	else if (EQN(in, "../", 3)) {	// Unix parent directory?
+	else if (EQN(in, "../", 3))     // Unix parent directory?
+	{
 	    *out++ = '-';
 	    end_of_dir = out;
 	    ch = '.';
 	    in += 2;
 	    SKIP_FOLLOWING_SLASHES(in);
 	    }
-	else {
-	    while (EQN(in, "./", 2)) {  // Ignore Unix "current dir"
-	    end_of_dir = out;
-	    in += 2;
-	    SKIP_FOLLOWING_SLASHES(in);
-	    ch = *in;
+	else
+	{
+	    while (EQN(in, "./", 2))    // Ignore Unix "current dir"
+	    {
+		end_of_dir = out;
+		in += 2;
+		SKIP_FOLLOWING_SLASHES(in);
+		ch = *in;
 	    }
 	}
 
@@ -624,7 +656,7 @@ vms_unix_mixed_filespec(char *in, char *out)
 	++in;
     }
 
-    *out = '\0';    // Terminate output file spec
+    *out = '\0';            // Terminate output file spec
 
     if (end_of_dir != NULL) // Terminate directory portion
 	*end_of_dir = ']';
@@ -659,9 +691,9 @@ vms_fixfilename(void *instring)
     }
 
 #ifdef DEBUG
-     char		 *tmpbuf = NULL;
-     tmpbuf = ALLOC_MULT(char, buflen);
-     strcpy(tmpbuf, instring);
+    char		 *tmpbuf = NULL;
+    tmpbuf = ALLOC_MULT(char, buflen);
+    strcpy(tmpbuf, instring);
 #endif
 
     Fspec_Rms = buf;				// for decc$to_vms
@@ -672,7 +704,7 @@ vms_fixfilename(void *instring)
     else if (strchr(instring,'"') == NULL)	// password in the path?
     {
 	// Seems it is a regular file, let guess that it is pure Unix fspec
-        if ( (strchr(instring,'[') == NULL) && (strchr(instring,'<') == NULL) &&
+	if ( (strchr(instring,'[') == NULL) && (strchr(instring,'<') == NULL) &&
 	     (strchr(instring,']') == NULL) && (strchr(instring,'>') == NULL) &&
 	     (strchr(instring,':') == NULL) )
 	{
@@ -698,25 +730,82 @@ vms_fixfilename(void *instring)
  * Remove version number from file name
  * we need it in some special cases as:
  * creating swap file name and writing new file
+ */
+
+/*
+ * 2025-05-13 SMS.
+ * Using $PARSE would be simpler and more accurate, if all-VMS (not
+ * mixed UNIX+VMS) path were ensured.  Meanwhile, to improve (imperfect)
+ * handling of extended name syntax:
+ *     o All characters (up to five (32767)) after semi-colon (or last
+ *       of multiple dots) must be numeric.
+ *     o Caret-escaped semi-colon (^;) or dot (^.) does not delimit
+ *       version.
+ * Whether it makes sense to detect syntax errors here is not entirely
+ * clear.  Currently, many invalid version strings are not treated as
+ * version strings.  (More could be.)
  */
     void
 vms_remove_version(void * fname)
 {
-    char_u	*cp;
-    char_u	*fp;
+    char_u	*dp;	        // Dot pointer
+    char_u	*rp;            // Right pointer
+    int		done = 0;
+    int		vdigits = 0;
 
-    if ((cp = vim_strchr( fname, ';')) != NULL) // remove version
-	*cp = '\0';
-    else if ((cp = vim_strrchr( fname, '.')) != NULL )
+    rp = (char_u *)fname+ strlen( (char *)fname)- 1;    // Rightmost char
+    while ((done == 0) && (rp > (char_u *)fname))       // Count digits
     {
-	if      ((fp = vim_strrchr( fname, ']')) != NULL ) {;}
-	else if ((fp = vim_strrchr( fname, '>')) != NULL ) {;}
-	else fp = fname;
+	if (isdigit( *rp))
+	{
+	    vdigits++;
+	    *rp--;
+	}
+	else
+	{
+	    done = 1;                                   // Quit at non-digit
+	}
+    } // while (Count digits)
+
+    if (vdigits  <= 5)                  // If likely version digits, check delimiter
+    {                                   // (Could check for <= 32767, not just five digits or fewer.)
+	if (*rp == (char_u)';')
+	{
+	    if ((rp >= (char_u *)fname) && (*(rp- 1) != (char_u)'^'))
+	    {                           // Unescaped ";"
+		*rp = '\0';             // Trim off ";nnn"
+	    }
+	}
+	else if (*rp == (char_u)'.')    // Last of multiple dots?
+	{
+	    if ((rp >= (char_u *)fname) && (*(rp- 1) != '^'))
+	    {                           // Unescaped dot.  Version requires previous one
+		dp = rp- 1;             // Scan chars before "."
+		done = 0;
+		while ((done == 0) && (dp >= (char_u *)fname))
+		{
+		    if ((*dp == ']') || (*dp == '>') || (*dp == ':') || (*dp == '/'))
+		    {                   // Possible VMS dev:[dir] delimiter (or UNIX "/")
+			if ((dp >= (char_u *)fname) && (*(dp- 1) != '^'))
+			{               // Unescaped dev:[dir] (or /) delimiter
+			    done = 1;   // No previous dot found in name
+			}
+		    }
+		    else if (*dp == '.')
+		    {                   // Possible dot delimiter
+			if ((dp >= (char_u *)fname) && (*(dp- 1) != '^'))
+			{               // Unescaped dot delimiter
+			    done = 1;   // Previous dot found in name
+			    *rp = '\0'; // Trim off ".nnn"
+			}
+		    }
+		    dp--;               // Next char to right
+		} // while
+	    }
+	}
+	// Else no version found to remove
+    } // if (vdigits  <= 5)
 
-	while ( *fp != '\0' && fp < cp )
-	    if ( *fp++ == '.' )
-		*cp = '\0';
-    }
     return ;
 }
 
@@ -750,25 +839,32 @@ RealWaitForChar(
     if (!iochan)
 	get_tty();
 
-    if (sec > 0) {
+    if (sec > 0)
+    {
 	// time-out specified; convert it to absolute time
-	// sec>0 requirement of lib$cvtf_to_internal_time()
+	// sec>0 requirement of lib$cvt[fs]_to_internal_time()
 
 	// get current time (number of 100ns ticks since the VMS Epoch)
 	status = sys$gettim(&time_curr);
 	if (status != SS$_NORMAL)
 	    return 0; // error
 	// construct the delta time
-#if __G_FLOAT==0
-# ifndef VAX
-	// IEEE is default on IA64, but can be used on Alpha too - but not on VAX
-	status = lib$cvts_to_internal_time(
+
+/* On all non-VAX hardware architectures, the "CC /FLOAT=option"
+ * determines the floating-point format.  The default format on Alpha
+ * is VAX; on IA64 and x86_64 it's IEEE.  But, except on VAX, the user
+ * can specify either.   What matters here is the actual floating-point
+ * format being used, not the hardware architecture.  Choose the
+ * appropriate time conversion function accordingly.
+ */
+#if __IEEE_FLOAT
+# define LIB_CVTX_TO_INTERNAL_TIME lib$cvts_to_internal_time // IEEE
+#else
+# define LIB_CVTX_TO_INTERNAL_TIME lib$cvtf_to_internal_time // VAX
+#endif // __IEEE_FLOAT CVTS
+
+	status = LIB_CVTX_TO_INTERNAL_TIME(
 		&convert_operation, &sec, &time_diff);
-# endif
-#else   // default on Alpha and VAX
-	status = lib$cvtf_to_internal_time(
-		&convert_operation, &sec, &time_diff);
-#endif
 	if (status != LIB$_NORMAL)
 	    return 0; // error
 	// add them up
@@ -780,7 +876,8 @@ RealWaitForChar(
 	    return 0; // error
     }
 
-    while (TRUE) {
+    while (TRUE)
+    {
 	// select()
 	status = sys$qiow(0, iochan, IO$_SENSEMODE | IO$M_TYPEAHDCNT, iosb,
 		0, 0, &typeahead, 8, 0, 0, 0, 0);
@@ -791,13 +888,18 @@ RealWaitForChar(
 	    return 1; // ready to read
 
 	// there's nothing to read; what now?
-	if (msec == 0) {
+	if (msec == 0)
+	{
 	    // immediate time-out; return impatiently
 	    return 0;
-	} else if (msec < 0) {
+	}
+	else if (msec < 0)
+	{
 	    // no time-out; wait on indefinitely
 	    return 1; // fakeout to force a wait in vms_read()
-	} else {
+	}
+	else
+	{
 	    // time-out needs to be checked
 	    status = sys$gettim(&time_curr);
 	    if (status != SS$_NORMAL)
@@ -814,3 +916,130 @@ RealWaitForChar(
 	}
     }
 }
+
+#if !defined( __VAX) && (__CRTL_VER >= 70301000)
+
+# include <stdio.h>
+# include <unixlib.h>
+
+// Structure to hold a DECC$* feature name and its desired value
+
+typedef struct
+   {
+   char *name;
+   int value;
+   } decc_feat_t;
+
+int vms_init_done = -1;
+
+decc_feat_t decc_feat_array[] = {
+
+   // Preserve command-line case with SET PROCESS/PARSE_STYLE=EXTENDED
+ { "DECC$ARGV_PARSE_STYLE", 1 },
+
+   // Preserve case for file names on ODS5 disks
+ { "DECC$EFS_CASE_PRESERVE", 1 },
+
+   // Enable multiple dots (and most characters) in ODS5 file names,
+   // while preserving VMS-ness of ";version"
+ { "DECC$EFS_CHARSET", 1 },
+
+   // List terminator
+ { (char *)NULL, 0 } };
+
+
+/* LIB$INITIALIZE initialization.
+ *
+ * On sufficiently recent non-VAX systems, set a collection of C RTL
+ * features without using the DECC$* logical name method.
+ *
+ * Note: Old VAX VMS versions may suffer from a linker complaint like
+ * this:
+ *
+ * %LINK-W-MULPSC, conflicting attributes for psect LIB$INITIALIZE
+ * in module LIB$INITIALIZE file SYS$COMMON:[SYSLIB]STARLET.OLB;1
+ *
+ * Using a LINK options file which includes a line like this one should
+ * stop this complaint:
+ *
+ * PSECT_ATTR=LIB$INITIALIZE,NOPIC
+ */
+
+/* vms_init()
+ *
+ * Uses LIB$INITIALIZE to set a collection of C RTL features without
+ * requiring the user to define the corresponding logical names.
+ *
+ * LIB$INITIALIZE initialization function
+ */
+
+static void
+vms_init(void)
+{
+    // Set the global flag to indicate that LIB$INITIALIZE worked
+
+    vms_init_done = 1;
+
+    int feat_index;
+    int feat_value;
+    int feat_value_max;
+    int feat_value_min;
+    int i;
+    int sts;
+
+    // Loop through all items in the decc_feat_array[]
+    for (i = 0; decc_feat_array[i].name != NULL; i++)
+    {
+	// Get the feature index
+	feat_index = decc$feature_get_index(decc_feat_array[i].name);
+	if (feat_index >= 0)
+	{
+	    // Valid item.  Collect its properties
+	    feat_value = decc$feature_get_value(feat_index, 1);
+	    feat_value_min = decc$feature_get_value(feat_index, 2);
+	    feat_value_max = decc$feature_get_value(feat_index, 3);
+
+	    if ((decc_feat_array[i].value >= feat_value_min) && (decc_feat_array[i].value <= feat_value_max))
+		// Valid value.  Set it if necessary
+		if (feat_value != decc_feat_array[i].value)
+		    sts = decc$feature_set_value(feat_index, 1, decc_feat_array[i].value);
+	    else
+		// Invalid DECC feature value
+		printf("INVALID DECC FEATURE VALUE, %d: %d <= %s <= %d.\n",
+			feat_value, feat_value_min, decc_feat_array[i].name, feat_value_max);
+	}
+	else
+	    // Invalid DECC feature name
+	    printf("UNKNOWN DECC FEATURE: %s.\n", decc_feat_array[i].name);
+    }
+}
+
+
+/* Get "vms_init()" into a valid, loaded LIB$INITIALIZE PSECT. */
+
+# pragma nostandard
+
+/* Establish the LIB$INITIALIZE PSECTs, with proper alignment and
+ * other attributes.  Note that "nopic" is significant only on VAX.
+ */
+# pragma extern_model save
+
+# pragma extern_model strict_refdef "LIB$INITIALIZE" 2, nopic, nowrt
+void (*const x_vms_init)() = vms_init;
+
+# pragma extern_model strict_refdef "LIB$INITIALIZ" 2, nopic, nowrt
+const int spare[ 8] = { 0 };
+
+# pragma extern_model restore
+
+// Fake reference to ensure loading the LIB$INITIALIZE PSECT
+
+# pragma extern_model save
+int LIB$INITIALIZE(void);
+# pragma extern_model strict_refdef
+int dmy_lib$initialize = (int) LIB$INITIALIZE;
+# pragma extern_model restore
+
+# pragma standard
+
+#endif // !defined( __VAX) && (__CRTL_VER >= 70301000)
